@@ -46,7 +46,7 @@ in this Software without prior written authorization from The Open Group.
  * THIS SOFTWARE.
  */
 
-#include	"xfs-config.h"
+#include	"config.h"
 
 #define	XK_LATIN1
 
@@ -177,48 +177,17 @@ GetDefaultPointSize(void)
 	return default_point_size;
 }
 
-Bool
-XpClientIsBitmapClient(ClientPtr client)
-{
-    return TRUE;
-}
-
-Bool
-XpClientIsPrintClient(ClientPtr client, FontPathElementPtr fpe)
-{
-    return FALSE;
-}
-
-void
-CopyISOLatin1Lowered(char *d, char *s, int length)
-{
-    register int i;
-    unsigned char *dest = (unsigned char *)d, *source = (unsigned char *)s;
-
-    for (i = 0; i < length; i++, source++, dest++) {
-	if ((*source >= XK_A) && (*source <= XK_Z))
-	    *dest = *source + (XK_a - XK_A);
-	else if ((*source >= XK_Agrave) && (*source <= XK_Odiaeresis))
-	    *dest = *source + (XK_agrave - XK_Agrave);
-	else if ((*source >= XK_Ooblique) && (*source <= XK_Thorn))
-	    *dest = *source + (XK_oslash - XK_Ooblique);
-	else
-	    *dest = *source;
-    }
-    *dest = '\0';
-}
-
 int
 strncmpnocase(
-    char       *first,
-    char       *second,
+    const char *first,
+    const char *second,
     int         n)
 {
-    register unsigned char *ap,
+    register const unsigned char *ap,
                *bp;
 
-    for (ap = (unsigned char *) first,
-	    bp = (unsigned char *) second;
+    for (ap = (const unsigned char *) first,
+	    bp = (const unsigned char *) second;
     /* SUPPRESS 112 */
 	    n > 0 && *ap && *bp; n--, ap++, bp++) {
 	register unsigned char a,
