@@ -58,7 +58,6 @@ in this Software without prior written authorization from The Open Group.
 #include	"misc.h"
 #include	"globals.h"
 #include	"servermd.h"
-#include	"cache.h"
 #include	"site.h"
 #include	"dispatch.h"
 #include	"extentst.h"
@@ -67,10 +66,6 @@ in this Software without prior written authorization from The Open Group.
 char       *ConnectionInfo;
 int         ConnInfoLen;
 
-Cache       serverCache;
-
-#define	SERVER_CACHE_SIZE	10000	/* for random server cacheables */
-
 static Bool create_connection_block(void);
 
 char       *configfilename;
@@ -109,7 +104,6 @@ main(int argc, char *argv[])
 	OsInit();
 	if (serverGeneration == 1) {
 	    /* do first time init */
-	    serverCache = CacheInit(SERVER_CACHE_SIZE);
 	    CreateSockets(OldListenCount, OldListen);
 	    InitProcVectors();
 	    clients = (ClientPtr *) fsalloc(MAXCLIENTS * sizeof(ClientPtr));
@@ -134,7 +128,6 @@ main(int argc, char *argv[])
 	if (!InitClientResources(serverClient))
 	    FatalError("couldn't init server resources\n");
 
-	InitExtensions();
 	InitAtoms();
 	InitFonts();
 	SetConfigValues();
@@ -152,8 +145,6 @@ main(int argc, char *argv[])
 #endif
 
 	/* clean up per-cycle stuff */
-	CacheReset();
-	CloseDownExtensions();
 	if ((dispatchException & DE_TERMINATE) || drone_server)
 	    break;
 	fsfree(ConnectionInfo);
